@@ -56,20 +56,19 @@ sub register {
   my $home = $app->home;
   $file = $home->rel_file($file) unless file_name_is_absolute $file;
   $mode = $home->rel_file($mode) if $mode && !file_name_is_absolute $mode;
+  $mode = undef unless $mode && -e $mode;
 
   # Read config file
   my $config = {};
   if (-e $file) { $config = $self->load($file, $conf, $app) }
 
-  # Check for default
-  elsif ($conf->{default}) {
-    $app->log->debug(qq{Config file "$file" not found, using default config.});
+  # Check for default and mode specific config file
+  elsif (!$conf->{default} && !$mode) {
+    die qq{Config file "$file" missing, maybe you need to create it?\n};
   }
-  else { die qq{Config file "$file" missing, maybe you need to create it?\n} }
 
   # Merge everything
-  $config = {%$config, %{$self->load($mode, $conf, $app)}}
-    if $mode && -e $mode;
+  $config = {%$config, %{$self->load($mode, $conf, $app)}} if $mode;
   $config = {%{$conf->{default}}, %$config} if $conf->{default};
   my $current = $app->defaults(config => $app->config)->config;
   %$current = (%$current, %$config);
